.. _client:

***********************************************
Classes representing Service Provider instances
***********************************************

:Author: Roland Hedberg
:Version: |version|

.. module:: Client
   :synopsis: Classes representing Service Provider instances.

Module
==========

.. automodule:: saml2.client
   :members: 

